docx\_parser\_converter.docx\_to\_txt package
=============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_to_txt.converters

Submodules
----------

.. toctree::
   :maxdepth: 4

   docx_parser_converter.docx_to_txt.docx_processor
   docx_parser_converter.docx_to_txt.docx_to_txt_converter
   docx_parser_converter.docx_to_txt.txt_generator

Module contents
---------------

.. automodule:: docx_parser_converter.docx_to_txt
   :members:
   :undoc-members:
   :show-inheritance:
